"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
function ensureDirectoryExists(filePath) {
    const dirname = path.dirname(filePath);
    if (fs.existsSync(dirname)) {
        return;
    }
    ensureDirectoryExists(dirname);
    fs.mkdirSync(dirname);
}
exports.ensureDirectoryExists = ensureDirectoryExists;
/**
 * Method to save multiple files on disk
 * @param fileMap key = filePath, value = file contents
 */
function createFiles(fileMap) {
    for (const filePath of fileMap.keys()) {
        ensureDirectoryExists(filePath);
        const writeStream = fs.createWriteStream(filePath);
        writeStream.write(fileMap.get(filePath));
        writeStream.end();
    }
}
exports.createFiles = createFiles;
function isDirectory(fsPath) {
    return fs.lstatSync(fsPath).isDirectory();
}
exports.isDirectory = isDirectory;
/**
 * Walk a given directory path and collect the files
 * @param dir Directory to walk
 * @param ignore Optional paths to ignore
 */
function walk(dir, ignore) {
    const paths = [];
    for (const file of fs.readdirSync(dir)) {
        const p = path.join(dir, file);
        if (isDirectory(p)) {
            paths.push(...walk(p, ignore));
        }
        else if (!ignore || !ignore.has(p)) {
            paths.push(p);
        }
    }
    return paths;
}
exports.walk = walk;
//# sourceMappingURL=fileSystemHandler.js.map